@@ -1,11 +1,10 @@
 --
--- (C) 2013-17 - ntop.org
+-- (C) 2013-20 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 require "lua_utils"
-require "top_talkers"
 require "db_utils"
 local json = require ("dkjson")
 
@@ -74,11 +73,15 @@ elseif action == "set" or action == "del" then
    if favourite_type == "talker" or favourite_type == "apps_per_host_pair" then
       if host ~= "" and host ~= nil then
 	 entry = host
-	 resolved = getResolvedAddress(hostkey2hostinfo(host))
+
+	 local hinfo = hostkey2hostinfo(host)
+	 resolved = hostinfo2label(hinfo)
 
 	 if peer ~= "" and peer ~= nil then
 	    entry = entry..','..peer
-	    resolved = resolved..','..getResolvedAddress(hostkey2hostinfo(peer))
+
+	    local hinfo = hostkey2hostinfo(peer)
+	    resolved = resolved..','..hostinfo2label(hinfo)
 	 end
       end
 
@@ -89,7 +92,9 @@ elseif action == "set" or action == "del" then
 	 resolved = interface.getnDPIProtoName(tonumber(l7_proto_id))
 	 if host ~= "" and host ~= nil then
 	    entry = entry..','..host
-	    resolved = resolved..','..getResolvedAddress(hostkey2hostinfo(host))
+
+	    local hinfo = hostkey2hostinfo(host)
+	    resolved = resolved..','..hostinfo2label(hinfo)
 	 end
       end
    end
