@@ -1,18 +1,20 @@
 --
--- (C) 2016-18 - ntop.org
+-- (C) 2016-20 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
-require "alert_utils"
+local alert_utils = require "alert_utils"
 
-interface.select(ifname)
+if not isEmptyString(_GET["ifid"]) then
+   interface.select(_GET["ifid"])
+end
 
 sendHTTPContentTypeHeader('text/html')
 
 if(_GET["status"] ~= nil) then
-   local num = getNumAlerts(_GET["status"], _GET)
+   local num = alert_utils.getNumAlerts(_GET["status"], _GET)
    print(tostring(num))
 end
