@@ -1,26 +1,24 @@
 --
--- (C) 2013-17 - ntop.org
+-- (C) 2013-20 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
-require "graph_utils"
+local graph_utils = require "graph_utils"
 require "historical_utils"
 
 sendHTTPContentTypeHeader('text/html')
 
-
 ifid = _GET["ifid"]
 direction = _GET["sflow_filter"]
 
 interface.select(ifid)
-host_info = url2hostinfo(_GET)
-host_ip = host_info["host"]
-host_vlan = host_info["vlan"]
-host = interface.getHostInfo(host_ip, host_vlan)
-host_ndpi_rrd_creation = ntop.getCache("ntopng.prefs.host_ndpi_rrd_creation")
+local host_info = url2hostinfo(_GET)
+local host_ip = host_info["host"]
+local host_vlan = host_info["vlan"]
+local host = interface.getHostInfo(host_ip, host_vlan)
 
 local now    = os.time()
 local ago1h  = now - 3600
@@ -80,7 +78,7 @@ local total = total_sent + total_recv
 print("<tr><td>Total</td><td class=\"text-right\">".. secondsToTime(host["total_activity_time"]) .."</td><td class=\"text-right\">" .. bytesToSize(total_sent) .. "</td><td class=\"text-right\">" .. bytesToSize(total_recv) .. "</td>")
 
 print("<td>")
-breakdownBar(total_sent, i18n("ndpi_page.sent"), total_recv, i18n("ndpi_page.rcvd"), 0, 100)
+graph_utils.breakdownBar(total_sent, i18n("ndpi_page.sent"), total_recv, i18n("ndpi_page.rcvd"), 0, 100)
 print("</td>\n")
 
 print("<td colspan=2 class=\"text-right\">" ..  bytesToSize(total).. "</td></tr>\n")
@@ -90,17 +88,14 @@ for _k in pairsByKeys(vals , desc) do
 
   if filter_pass(host["ndpi"][k]) then
     print("<tr><td>")
-    fname = getRRDName(ifid, hostinfo2hostkey(host_info), k..".rrd")
-    if(ntop.exists(fname)) then
-      print("<A HREF=\""..ntop.getHttpPrefix().."/lua/host_details.lua?ifid="..ifid.."&"..hostinfo2url(host_info) .. "&page=historical&rrd_file=".. k ..".rrd\">"..k.." "..formatBreed(host["ndpi"][k]["breed"]).."</A>")
-    else
-      print(k.." "..formatBreed(host["ndpi"][k]["breed"]))
-    end
-    
+
+    local host_href = hostinfo2detailshref(host_info, {page = "historical", ts_schema = "host:ndpi", protocol = k}, k.." "..formatBreed(host["ndpi"][k]["breed"]))
+    print(host_href)
+
     t = host["ndpi"][k]["bytes.sent"]+host["ndpi"][k]["bytes.rcvd"]
 
     if((host["ndpi"][k]["bytes.sent"] == 0) and (host["ndpi"][k]["bytes.rcvd"] > 0)) then
-       print(" <i class=\"fa fa-warning fa-lg\" style=\"color: orange;\"></i>")
+       print(" <i class=\"fas fa-exclamation-triangle fa-lg\" style=\"color: orange;\"></i>")
     end
 
     historicalProtoHostHref(getInterfaceId(ifname), host, nil, protos[k], nil)
@@ -110,18 +105,9 @@ for _k in pairsByKeys(vals , desc) do
     print("<td class=\"text-right\">" .. bytesToSize(host["ndpi"][k]["bytes.sent"]) .. "</td><td class=\"text-right\">" .. bytesToSize(host["ndpi"][k]["bytes.rcvd"]) .. "</td>")
 
     print("<td>")
-    breakdownBar(host["ndpi"][k]["bytes.sent"], i18n("ndpi_page.sent"), host["ndpi"][k]["bytes.rcvd"], i18n("ndpi_page.rcvd"), 0, 100)
+    graph_utils.breakdownBar(host["ndpi"][k]["bytes.sent"], i18n("ndpi_page.sent"), host["ndpi"][k]["bytes.rcvd"], i18n("ndpi_page.rcvd"), 0, 100)
     print("</td>\n")
 
     print("<td class=\"text-right\">" .. bytesToSize(t).. "</td><td class=\"text-right\">" .. round((t * 100)/total, 2).. " %</td></tr>\n")
   end
 end
-if host_ndpi_rrd_creation ~= "1" then
-print("<tr><td colspan=\"7\"> <small> <b>NOTE</b>:<ul>")
-print("<li>"..i18n("ndpi_page.note_historical_per_protocol_traffic",{url=ntop.getHttpPrefix().."/lua/admin/prefs.lua",flask_icon="<i class=\"fa fa-flask\"></i>"}).." ")
-print(" "..i18n("ndpi_page.note_rrd_samples"))
-print("<li>"..i18n("ndpi_page.note_possible_probing_alert",{icon="<i class=\"fa fa-warning fa-sm\" style=\"color: orange;\"></i>",url=ntop.getHttpPrefix().."/lua/host_details.lua?ifid="..ifid.."&host=".._GET["host"].."&page=historical"}))
-print("<li>"..i18n("ndpi_page.note_protocol_usage_time"))
-print("</ul>")
-end
-print("</small> </p></td></tr>")
