@@ -1,5 +1,5 @@
 --
--- (C) 2013-17 - ntop.org
+-- (C) 2013-20 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,15 +7,15 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
+local page_utils = require("page_utils")
+
 sendHTTPContentTypeHeader('text/html')
 
-ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
-
-active_page = "hosts"
+page_utils.set_active_menu_entry(page_utils.menu_entries.http_servers)
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
+page_utils.print_page_title(i18n("http_servers_stats.local_http_servers"))
 
 print [[
-      <hr>
       <div id="table-http"></div>
 	 <script>
 	 var url_update = "]]
@@ -31,7 +31,7 @@ print [[
 			url: url_update ,
 	 ]]
 
-print('title: "' .. i18n("http_servers_stats.local_http_servers") .. '",\n')
+print('title: "",\n')
 print ('rowCallback: function ( row ) { return http_table_setID(row); },')
 
 -- Set the preference table
@@ -73,8 +73,45 @@ print [[
 				 },
 			  ]]
 
+print [[
+			     {
+			     title: "]] print(i18n("http_servers_stats.bytes_sent")) print[[",
+				 field: "column_bytes_sent",
+				 sortable: true,
+                             css: {
+			        textAlign: 'center'
+			     }
 
-ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/http_servers_stats_top.inc")
+				 },
+			     {
+			     title: "]] print(i18n("http_servers_stats.bytes_received")) print[[",
+				 field: "column_bytes_rcvd",
+				 sortable: true,
+                             css: {
+			        textAlign: 'center'
+			     }
+
+				 },
+
+			     {
+			     title: "]] print(i18n("http_servers_stats.total_requests")) print[[",
+				 field: "column_http_requests",
+				 sortable: true,
+                             css: {
+			        textAlign: 'center'
+			     }
+
+				 },
+			     {
+			     title: "]] print(i18n("http_servers_stats.actual_requests")) print[[",
+				 field: "column_act_num_http_requests",
+				 sortable: true,
+                             css: {
+			        textAlign: 'center'
+			     }
+
+				 },
+]]
 
 print [[
 			     ]
