@@ -1,39 +1,37 @@
-local host_pools_utils = require 'host_pools_utils'
+require("lua_utils")
 require("prefs_utils")
 
+local is_admin = isAdministrator()
+local template = require("template_utils")
+
 print [[
 
- <style type='text/css'>
-.largegroup {
-    width:500px
-}
-</style>
 <div id="password_dialog" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="password_dialog_label" aria-hidden="true">
   <div class="modal-dialog">
     <div class="modal-content">
       <div class="modal-header">
-  <button type="button" class="close" data-dismiss="modal" aria-hidden="true"><i class="fa fa-times"></i></button>
-  <h3 id="password_dialog_label">Manage User <span id="password_dialog_title"></span></h3>
-</div>
+        <h5 class="modal-title" id="password_dialog_label">]] print(i18n("manage_users.manage_user_x", {user=[[<span class="password_dialog_title"></span>]]})) print[[ </h5>
+        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">
+          <span aria-hidden="true">&times;</span>
+        </button>
+      </div>
 
 <div class="modal-body">
 
   <div class="tabbable"> <!-- Only required for left/right tabs -->
-  <ul class="nav nav-tabs" role="tablist" id="edit-user-container">
-    <li class="active"><a href="#change-password-dialog" role="tab" data-toggle="tab"> Password </a></li>
+  <div class='card'>
+  <div class='card-header'>
+  <ul class="nav nav-tabs card-header-tabs" role="tablist" id="edit-user-container">
+    <li class="nav-item active"><a class="nav-link active" href="#change-password-dialog" role="tab" data-toggle="tab"> ]] print(i18n("login.password")) print[[ </a></li>
 ]]
 
-local captive_portal_user = false
-if is_captive_portal_active and _GET["captive_portal_users"] ~= nil then
-   captive_portal_user = true
-end
-
-if(user_group=="administrator") then
-   print[[<li><a href="#change-prefs-dialog" role="tab" data-toggle="tab"> Preferences </a></li>]]
+if(is_admin) then
+   print[[<li class="nav-item" id="li_change_prefs"><a class="nav-link" href="#change-prefs-dialog" role="tab" data-toggle="tab"> ]] print(i18n("prefs.preferences")) print[[ </a></li>]]
 end
    print[[
   </ul>
-  <div class="tab-content">
+  </div>
+  <div class="card-body tab-content">
   <div class="tab-pane active" id="change-password-dialog">
 
   <div id="password_alert_placeholder"></div>
@@ -44,192 +42,162 @@ end
   password_alert.success = function(message) { $('#password_alert_placeholder').html('<div class="alert alert-success"><button type="button" class="close" data-dismiss="alert">x</button>' + message + '</div>'); }
 </script>
 
-  <form data-toggle="validator" id="form_password_reset" class="form-inline" method="post" action="]] print(ntop.getHttpPrefix()) print[[/lua/admin/password_reset.lua">
+  <form data-toggle="validator" id="form_password_reset" method="post" action="]] print(ntop.getHttpPrefix()) print[[/lua/admin/password_reset.lua" accept-charset="UTF-8">
 ]]
-print('<input id="csrf" name="csrf" type="hidden" value="'..ntop.getRandomCSRFValue()..'" />\n')
+
+   print('<input name="csrf" type="hidden" value="'..ntop.getRandomCSRFValue()..'" />\n')
+
 print [[
     <input id="password_dialog_username" type="hidden" name="username" value="" />
 
 <div class="control-group">
    ]]
 
-local user_group = ntop.getUserGroup()
 local col_md_size = "6"
 
-print('<br><div class="row">')
-
-if(user_group ~= "administrator") then
+if(not is_admin) then
    col_md_size = "4"
 print [[
-  <div class='form-group col-md-]] print(col_md_size) print[[ has-feedback'>
-      <label for="" class="control-label">Old Password</label>
-      <div class="input-group"><span class="input-group-addon"><i class="fa fa-lock"></i></span>
-        <input id="old_password_input" type="password" name="old_password" value="" class="form-control" required>
+  <div class='form-group'>
+  <label for="old_password_input">]] print(i18n("manage_users.old_password")) print[[</label>
+  <div class='input-group mb-]] print(col_md_size) print[[ has-feedback'>
+      <div class="input-group-prepend">
+        <span class="input-group-text"><i class="fas fa-lock"></i></span>
       </div>
+      <input id="old_password_input" type="password" name="old_password" value="" class="form-control" required>
+  </div>
   </div>
    ]]
 end
 
 print [[
-  <div class='form-group has-feedback col-md-]] print(col_md_size) print[['>
-      <label for="" class="control-label">New Password</label>
-      <div class="input-group"><span class="input-group-addon"><i class="fa fa-lock"></i></span>
+  <div class='form-group'>
+    <label for="new_password_input">]] print(i18n("manage_users.new_password")) print[[</label>
+    <div class='input-group mb-]] print(col_md_size) print[['>
+        <div class="input-group-prepend"><span class="input-group-text">
+          <i class="fas fa-lock"></i></span>
+        </div>
         <input id="new_password_input" type="password" name="new_password" value="" class="form-control" pattern="]] print(getPasswordInputPattern()) print[[" required>
-      </div>
+    </div>
   </div>
 
-  <div class='form-group has-feedback col-md-]] print(col_md_size) print[['>
-      <label for="" class="control-label">Confirm New Password</label>
-      <div class="input-group"><span class="input-group-addon"><i class="fa fa-lock"></i></span>
+  <div class='form-group'>
+  <label for="confirm_new_password_input">]] print(i18n("manage_users.new_password_confirm")) print[[</label>
+  <div class='input-group md-]] print(col_md_size) print[['>
+      <div class="input-group-prepend">
+        <span class="input-group-text"><i class="fas fa-lock"></i></span>
+      </div>
         <input id="confirm_new_password_input" type="password" name="confirm_password" value="" class="form-control" pattern="]] print(getPasswordInputPattern()) print[[" required>
-      </div>
   </div>
-</div>
+  </div>
 
-<div><small>Allowed characters are ISO 8859-1 (latin1) upper and lower case letters, numbers and special symbols.  </small></div>
+
+<div><small>]] print(i18n("manage_users.allowed_passwd_charset")) print[[.  </small></div>
 
 <br>
 
-<div class="row">
-    <div class="form-group col-md-12 has-feedback">
-      <button id="password_reset_submit" class="btn btn-primary btn-block">Change User Password</button>
+    <div class="has-feedback text-right">
+      <button id="password_reset_submit" class="btn btn-primary">]] print(i18n("manage_users.change_user_password")) print[[</button>
     </div>
-</div>
 
 </form>
 </div> <!-- closes div "change-password-dialog" -->
 ]]
 
-if(user_group=="administrator") then
+if(is_admin) then
 
 print [[
 </div>
 <div class="tab-pane" id="change-prefs-dialog">
 
-  <form data-toggle="validator" id="form_pref_change" class="form-inline" method="post" action="]] print(ntop.getHttpPrefix()) print[[/lua/admin/change_user_prefs.lua">
-    <input id="csrf" name="csrf" type="hidden" value="]] print(ntop.getRandomCSRFValue()) print[[" />
+  <form data-toggle="validator" id="form_pref_change" method="post" action="]] print(ntop.getHttpPrefix()) print[[/lua/admin/change_user_prefs.lua">
+    <input name="csrf" type="hidden" value="]] print(ntop.getRandomCSRFValue()) print[[" />
   <input id="pref_dialog_username" type="hidden" name="username" value="" />
 
-<br>
-]]
-
-if not captive_portal_user then
-   print[[
-<div class="row">
-  <div class='col-md-6 form-group has-feedback'>
-      <label class="input-label">User Role</label>
-      <div class="input-group" style="width:100%;">
+  <div class='form-group'>
+  <label for="host_role_select">]] print(i18n("manage_users.user_role")) print[[</label>
+  <div class='input-group mb-6'>
         <select id="host_role_select" name="user_role" class="form-control">
-          <option value="unprivileged">Non Privileged User</option>
-          <option value="administrator">Administrator</option>
+          <option value="unprivileged">]] print(i18n("manage_users.non_privileged_user")) print[[</option>
+          <option value="administrator">]] print(i18n("manage_users.administrator")) print[[</option>
         </select>
-      </div>
+  </div>
   </div>
 
-  <div class='col-md-6 form-group has-feedback'>
-      <label class="form-label">Allowed Interface</label>
-      <div class="input-group" style="width:100%;">
+  <div id="unprivileged_manage_input">
+
+  <div class='form-group'>
+  <label for="allowed_interface">]] print(i18n("manage_users.allowed_interface")) print[[</label>
+  <div class='input-group mb-6'>
         <select name="allowed_interface" id="allowed_interface" class="form-control">
-          <option value="">Any Interface</option>
+          <option value="">]] print(i18n("manage_users.any_interface")) print[[</option>
 ]]
    for _, interface_name in pairsByValues(interface.getIfNames(), asc) do
       -- io.write(interface_name.."\n")
-      print('<option value="'..getInterfaceId(interface_name)..'"> '..interface_name..'</option>')
+      print('<option value="'..getInterfaceId(interface_name)..'"> '..getHumanReadableInterfaceName(interface_name)..'</option>')
    end
    print[[
         </select>
+  </div>
+  </div>
+
+  <div class='form-group'>
+    <label for="networks_input">]] print(i18n("manage_users.allowed_networks")) print[[</label>
+    <div class='input-group mb-6'>
+      <input id="networks_input" type="text" name="allowed_networks" value="" class="form-control" required>
+      <small>]] print(i18n("manage_users.allowed_networks_descr")) print[[ 192.168.1.0/24,172.16.0.0/16</small>
     </div>
   </div>
-</div>
 
-<br>
 
-<div class="row">
-    <div class="form-group col-md-12 has-feedback">
-      <label class="control-label">Allowed Networks</label>
-      <div class="input-group"><span class="input-group-addon"><span class="glyphicon glyphicon-tasks"></span></span>
-        <input id="networks_input" type="text" name="allowed_networks" value="" class="form-control" required>
-      </div>
-      <small>Comma separated list of networks this user can view. Example: 192.168.1.0/24,172.16.0.0/16</small>
-    </div>
-</div>
+    <div class="form-group mb-6">
+      <div class="form-check">]]
 
-]]
+    print(template.gen("on_off_switch.html", {
+     id = "allow_pcap_input",
+     label = i18n("manage_users.allow_pcap_download_descr"),
+    }))
 
-else -- captive portal user
-   print[[
-
-<div class="row">
-    <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">Host Pool</label>
-      <div class="input-group" style="width:100%;">
-        <input id="old_host_pool_id" type="hidden" name="old_host_pool_id" value="" />
-        <select name="host_pool_id" id="host_pool_id" class="form-control" disabled>
-
-]]
-
-   local pools = host_pools_utils.getPoolsList(getInterfaceId(ifname))
-   local no_pools = true
-
-   for _, pool in ipairs(pools) do
-      if pool.id ~= host_pools_utils.DEFAULT_POOL_ID then
-        print('<option value="'.. pool.id ..'"> '.. pool.name ..'</option>')
-        no_pools = false
-      end
-   end
-
-   print[[
-        </select>
+    print[[
       </div>
     </div>
 
-    <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">Authentication Lifetime</label>
-      <div class="input-group">
-        <label class="radio-inline"><input type="radio" id="lifetime_unlimited" name="lifetime_unlimited" checked>Unlimited</label>
-        <label class="radio-inline"><input type="radio" id="lifetime_limited" name="lifetime_limited">Expires after</label>
-      </div>
-    </div>
-</div>
-
-<div class="row">
-    <div class="form-group col-md-6 has-feedback">
     </div>
 
-    <div class="col-md-6 has-feedback text-center">
-
-      <table class="form-group" id="lifetime_selection_table">
-        <tr>
-
-          <td style="vertical-align:top;">
-]]
-   --   require("prefs_utils")
-   local res = prefsResolutionButtons("hd", 3600, "user_lifetime_sel")
-   print[[
-          </td>
-          <td style="padding-left: 2em;">
-        <input class="form-control text-right" style="display:inline; width:5em; padding-right:1em;" name="lifetime_secs" id="lifetime_secs" type="number" data-min="3600" value="]] print(tostring(res)) print[[">
-          </td>
-        </tr>
-      </table>
-    </div>
-</div>
+    <script>
+    function toggleUserSettings() {
+      if ($("#host_role_select").val() == "unprivileged")
+        $('#unprivileged_manage_input').show();
+      else
+        $('#unprivileged_manage_input').hide();
+    }
+    $("#host_role_select").change(function() { toggleUserSettings(); })
+    </script>
 
 ]]
-end
 
 print[[
+  <div class='form-group'>
+    <label for="user_language">]] print(i18n("language")) print[[</label>
+    <div class='input-group mb-6'>
+      <div class="input-group-prepend">
+        <span class="input-group-text"><i class="fas fa-language" aria-hidden="true"></i></span>
+      </div>
+      <select name="user_language" id="user_language" class="form-control">]]
 
-<br>
-
-<div class="row">
-    <div class="form-group col-md-12 has-feedback">
-      <button id="pref_change" class="btn btn-primary btn-block">Change User Preferences</button>
+for _, lang in ipairs(locales_utils.getAvailableLocales()) do
+   print('<option value="'..lang["code"]..'">'..i18n("locales." .. lang["code"])..'</option>')
+end
+print[[
+        </select>
     </div>
-</div>
-
-<br>
+    </div>
+]]
 
+print[[
+    <div class="has-feedback text-right">
+      <button id="pref_change" class="btn btn-primary">]] print(i18n("manage_users.change_user_preferences")) print[[</button>
+    </div>
   </form>
 </div> <!-- closes div "change-prefs-dialog" -->
 ]]
@@ -239,13 +207,13 @@ print [[<script>
   $("#lifetime_unlimited").click(function() {
     $("#lifetime_selection_table label").attr("disabled", "disabled");
     $("#lifetime_selection_table input").attr("disabled", "disabled");
-    $("#lifetime_limited").removeAttr("checked");
+    $("#lifetime_limited").removeAttr("checked").prop("checked", false);
   });
 
   $("#lifetime_limited").click(function() {
     $("#lifetime_selection_table input").removeAttr("disabled");
     $("#lifetime_selection_table label").removeAttr("disabled");
-    $("#lifetime_unlimited").removeAttr("checked");
+    $("#lifetime_unlimited").removeAttr("checked").prop("checked", false);
   });
 
   function isValid(str) { /* return /^[\w%]+$/.test(str); */ return true; }
@@ -267,10 +235,10 @@ print [[<script>
       password_alert.error("Passwords don't match"); return(false);
     }
 
-    // escape characters to send out valid latin-1 encoded characters
-    $('#old_password_input').val(escape($('#old_password_input').val()))
-    $('#new_password_input').val(escape($('#new_password_input').val()))
-    $('#confirm_new_password_input').val(escape($('#confirm_new_password_input').val()))
+    // Don't do any escape, form contain Unicode UTF-8 encoded chars
+    // $('#old_password_input').val(escape($('#old_password_input').val()))
+    // $('#new_password_input').val(escape($('#new_password_input').val()))
+    // $('#confirm_new_password_input').val(escape($('#confirm_new_password_input').val()))
 
     $.ajax({
       type: frmpassreset.attr('method'),
@@ -288,7 +256,7 @@ print [[<script>
           password_alert.error(response.message);
     ]]
 
-if(user_group ~= "administrator") then
+if(not is_admin) then
    print('$("old_password_input").text("");\n');
 end
 
@@ -304,12 +272,6 @@ print [[
 
   frmprefchange.submit(function () {
   var ok = true;
-
-]]
-
-if not captive_portal_user then
-
-print[[
   if($("#networks_input").val().length == 0) {
      password_alert.error("Network list not specified");
      ok = false;
@@ -317,42 +279,32 @@ print[[
      var arrayOfStrings = $("#networks_input").val().split(",");
 
      for (var i=0; i < arrayOfStrings.length; i++) {
-	if(!is_network_mask(arrayOfStrings[i])) {
+	if(!NtopUtils.is_network_mask(arrayOfStrings[i])) {
 	   password_alert.error("Invalid network list specified ("+arrayOfStrings[i]+")");
 	   ok = false;
 	}
      }
   }
-]]
-
-end
-
-print[[
   if(ok) {
-]]
-
-if captive_portal_user == true then
-  print[[
-        /* Converts expire resolution into appropriate value */
-        resol_selector_finalize(frmprefchange);]]
-end
-
-print[[
     $.ajax({
       type: frmprefchange.attr('method'),
       url: frmprefchange.attr('action'),
       data: frmprefchange.serialize(),
       success: function (response) {
         if(response.result == 0) {
+
+          const destURL = new URL(window.location);
+          destURL.searchParams.delete('user');
+
           password_alert.success(response.message);
-          window.location.href= window.location.href;
+          window.location.href= destURL.toString();
        } else
           password_alert.error(response.message);
       }
     });
    }
 
-    return false;   
+    return false;
    });
 </script>
 
@@ -365,19 +317,25 @@ print[[
 function reset_pwd_dialog(user) {
       $.getJSON(']] print(ntop.getHttpPrefix()) print[[/lua/admin/get_user_info.lua?username='+user, function(data) {
 
-      $('#password_dialog_title').text(data.username);
+      $('.password_dialog_title').text(data.username);
       $('#password_dialog_username').val(data.username);
       $('#pref_dialog_username').val(data.username);
       $('#old_password_input').val('');
       $('#new_password_input').val('');
       $('#confirm_password_input').val('');
-      $('#host_role_select option[value = '+data.group+']').attr('selected','selected');
+      $('#host_role_select').val(data.group);
+      if(data.username === "admin")
+        $('#host_role_select').attr("disabled", "disabled");
+      else
+        $('#host_role_select').removeAttr("disabled");
+      toggleUserSettings();
       $('#networks_input').val(data.allowed_nets);
-      $('#allowed_interface option').filter(function () {
-        return $(this).html().trim() == data.allowed_ifname;
-      }).attr('selected','selected');
-      // $('#allowed_interface option[value = "'+data.allowed_ifname+'"]').attr('selected','selected');
+      $('#allowed_interface option[value="' + data.allowed_if_id + '"]').attr('selected','selected');
 
+
+      if(data.language !== "")
+        $('#user_language option[value="' + data.language + '"]').attr('selected','selected');
+      $('#allow_pcap_input').prop('checked', data.allow_pcap_download === true ? true : false);
       if(data.host_pool_id) {
         $('#old_host_pool_id').val(data.host_pool_id);
         $('#host_pool_id option[value = '+data.host_pool_id+']').attr('selected','selected');
@@ -415,6 +373,7 @@ $('#password_reset_submit').click(function() {
 </div>
 </div>
 </div>
+</div>
 </div> <!-- password_dialog -->
 
 			    ]]
