@@ -6,6 +6,34 @@ local throughput_type = getThroughputType()
 
 local now = os.time()
 
+function printMacHosts(mac)
+   local mac_hosts = interface.getMacHosts(mac)
+   local num_hosts = table.len(mac_hosts)
+
+   if num_hosts > 0 then
+      local first_host
+
+      for _, h in pairsByKeys(mac_hosts, asc) do
+	 first_host = h
+	 break
+      end
+
+      local url = ntop.getHttpPrefix().."/lua/hosts_stats.lua?mac="..mac
+      local host_url = hostinfo2detailsurl(first_host)
+      local host_label = first_host["ip"]
+
+      if num_hosts > 2 then
+	 return i18n("mac_details.and_n_more_hosts", {host_url = host_url, host_label = host_label, url = url, num = num_hosts})
+      elseif num_hosts > 1 then
+	 return i18n("mac_details.and_one_more_host", {host_url = host_url, host_label = host_label, url = url})
+      else
+	 return i18n("mac_details.mac_host", {host_url = host_url, host_label = host_label})
+      end
+   end
+
+   return ''
+end
+
 function macAddIcon(mac, pre)
    local pre = pre or mac
    if not isSpecialMac(mac) then
@@ -31,15 +59,10 @@ function mac2record(mac)
    record["column_mac"] = mac2link(mac)
 
    if(mac.fingerprint ~= "") then
-      record["column_mac"] = record["column_mac"]..' <i class="fa fa-hand-o-up fa-lg" aria-hidden="true" title="DHCP Fingerprinted"></i>'
+      record["column_mac"] = record["column_mac"]..' <i class="fas fa-hand-o-up fa-lg" aria-hidden="true" title="DHCP Fingerprinted"></i>'
       -- io.write(mac.fingerprint.."\n")
    end
-
-   if(mac.dhcpHost) then
-      record["column_mac"] = record["column_mac"]..'  <i class="fa fa-flash fa-lg" aria-hidden="true" title="DHCP Host"></i>'
-   end
    
-   record["column_mac"] = record["column_mac"]..getOperatingSystemIcon(mac.operatingSystem)   
    local manufacturer = get_manufacturer_mac(mac["mac"])
    if(manufacturer == nil) then manufacturer = "" end
 
@@ -61,8 +84,8 @@ function mac2record(mac)
    record["column_since"] = secondsToTime(now - mac["seen.first"]+1)
 
    local sent2rcvd = round((mac["bytes.sent"] * 100) / (mac["bytes.sent"] + mac["bytes.rcvd"]), 0)
-   record["column_breakdown"] = "<div class='progress'><div class='progress-bar progress-bar-warning' style='width: "
-      .. sent2rcvd .."%;'>Sent</div><div class='progress-bar progress-bar-info' style='width: " .. (100-sent2rcvd) .. "%;'>Rcvd</div></div>"
+   record["column_breakdown"] = "<div class='progress'><div class='progress-bar bg-warning' style='width: "
+      .. sent2rcvd .."%;'>Sent</div><div class='progress-bar bg-info' style='width: " .. (100-sent2rcvd) .. "%;'>Rcvd</div></div>"
 
    if(throughput_type == "pps") then
       record["column_thpt"] = pktsToSize(mac["throughput_pps"])
